@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2004-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -395,6 +395,9 @@ namespace gloox
     if( tag->hasChild( "sm", XMLNS, XMLNS_STREAM_MANAGEMENT ) )
       features |= StreamFeatureStreamManagement;
 
+    if( tag->hasChild( "csi", XMLNS, XMLNS_CLIENT_STATE_INDICATION ) )
+      features |= StreamFeatureClientStateIndication;
+
     if( features == 0 )
       features = StreamFeatureIqAuth;
 
