@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -56,12 +56,12 @@ namespace gloox
 
   static inline StanzaErrorType stanzaErrorType( const std::string& type )
   {
-    return (StanzaErrorType)util::lookup( type, errValues );
+    return static_cast<StanzaErrorType>( util::lookup( type, errValues ) );
   }
 
   static inline StanzaError stanzaError( const std::string& type )
   {
-    return (StanzaError)util::lookup( type, stanzaErrValues );
+    return static_cast<StanzaError>( util::lookup( type, stanzaErrValues ) );
   }
 
   Error::Error( const Tag* tag )
