@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2004-2016 by Jakob Schröter <js@camaya.net>
+ *  Copyright (c) 2004-2017 by Jakob Schröter <js@camaya.net>
  *  This file is part of the gloox library. http://camaya.net/gloox
  *
  *  This software is distributed under a license. The full license
@@ -53,8 +53,11 @@ class MessageTest : public MessageSessionHandler, ConnectionListener, LogHandler
     void start()
     {
 
-      JID jid( "hurkhurk@example.net/gloox" );
-      j = new Client( jid, "hurkhurks" );
+      JID jid( "admin@jabba.us/gloox" );
+      j = new Client( jid, "test" );
+//       j->setServer ("127.0.0.1");
+//       j->setPort( 6222 );
+//       j->setTls( TLSDisabled );
       j->registerConnectionListener( this );
       j->registerMessageSessionHandler( this, 0 );
       j->disco()->setVersion( "messageTest", GLOOX_VERSION, "Linux" );
@@ -117,11 +120,12 @@ class MessageTest : public MessageSessionHandler, ConnectionListener, LogHandler
       time_t from( info.date_from );
       time_t to( info.date_to );
 
-      printf( "status: %d\nissuer: %s\npeer: %s\nprotocol: %s\nmac: %s\ncipher: %s\ncompression: %s\n"
-              "from: %s\nto: %s\n",
+      printf( "status: %d\nissuer: %s\npeer: %s\nprotocol: %s\nmac: %s\ncipher: %s\ncompression: %s\n",
               info.status, info.issuer.c_str(), info.server.c_str(),
               info.protocol.c_str(), info.mac.c_str(), info.cipher.c_str(),
-              info.compression.c_str(), ctime( &from ), ctime( &to ) );
+              info.compression.c_str() );
+      printf( "from: %s", ctime( &from ) );
+      printf( "to:   %s", ctime( &to ) );
       return true;
     }
 
