@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2006-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -55,7 +55,7 @@ namespace gloox
     if( !tag || tag->xmlns() != XMLNS_IBB )
       return;
 
-    m_type = (IBBType)util::lookup( tag->name(), typeValues );
+    m_type = static_cast<IBBType>( util::lookup( tag->name(), typeValues ) );
     m_blockSize = atoi( tag->findAttribute( "block-size" ).c_str() );
     m_seq = atoi( tag->findAttribute( "seq" ).c_str() );
     m_sid = tag->findAttribute( "sid" );
@@ -151,6 +151,10 @@ namespace gloox
           m_handler->handleBytestreamOpen( this );
           m_open = true;
         }
+        else if( context == IBBData && m_handler )
+        {
+          m_handler->handleBytestreamDataAck( this );
+        }
         break;
       case IQ::Error:
         closed();
@@ -185,13 +189,16 @@ namespace gloox
       return true;
     }
 
-    if( ( m_lastChunkReceived + 1 ) != i->seq() )
+    if( ++m_lastChunkReceived != i->seq() )
     {
       m_open = false;
       returnError( iq.from(), iq.id(), StanzaErrorTypeModify, StanzaErrorItemNotFound );
       return false;
     }
 
+    if( m_lastChunkReceived == 65535 )
+      m_lastChunkReceived = -1;
+
     if( i->data().empty() )
     {
       m_open = false;
@@ -201,7 +208,7 @@ namespace gloox
 
     returnResult( iq.from(), iq.id() );
     m_handler->handleBytestreamData( this, i->data() );
-    m_lastChunkReceived++;
+
     return true;
   }
 
