@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -49,13 +49,13 @@ namespace gloox
     if( type.empty() )
       m_subtype = Available;
     else
-      m_subtype = (PresenceType)util::lookup( type, msgTypeStringValues );
+      m_subtype = static_cast<PresenceType>( util::lookup( type, msgTypeStringValues ) );
 
     if( m_subtype == Available )
     {
       Tag* t = tag->findChild( "show" );
       if( t )
-        m_subtype = (PresenceType)util::lookup( t->cdata(), msgShowStringValues );
+        m_subtype = static_cast<PresenceType>( util::lookup( t->cdata(), msgShowStringValues ) );
     }
 
     const TagList& c = tag->children();
