@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2016 by Jakob Schröter <js@camaya.net>
+  Copyright (c) 2007-2017 by Jakob Schröter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -82,7 +82,7 @@ namespace gloox
 
     static inline SubscriptionType subscriptionType( const std::string& subscription )
     {
-      return (SubscriptionType)util::lookup( subscription, subscriptionValues );
+      return static_cast<SubscriptionType>( util::lookup( subscription, subscriptionValues ) );
     }
 
     static inline const std::string subscriptionValue( SubscriptionType subscription )
@@ -96,7 +96,7 @@ namespace gloox
 
     static inline AffiliationType affiliationType( const std::string& affiliation )
     {
-      return (AffiliationType)util::lookup( affiliation, affiliationValues );
+      return static_cast<AffiliationType>( util::lookup( affiliation, affiliationValues ) );
     }
 
     static inline const std::string affiliationValue( AffiliationType affiliation )
